summaryrefslogtreecommitdiff
path: root/sys/dev/isa/if_el.c
diff options
context:
space:
mode:
authorTheo de Raadt <deraadt@cvs.openbsd.org>1995-12-27 22:06:49 +0000
committerTheo de Raadt <deraadt@cvs.openbsd.org>1995-12-27 22:06:49 +0000
commit19c4b654cc723df0e419fd9f12197f491b1bc1d4 (patch)
treee1ec3cdc5db2c1ca3593846ae053d0595186ead5 /sys/dev/isa/if_el.c
parent043773b2a500f1f422b5db3eca46befb28d8a7af (diff)
from netbsd:
The IST_* and IPL_* constants are not bus-specific; don't treat them as such. Change splimp -> splnet in Ethernet, ARCnet, and FDDI drivers.
Diffstat (limited to 'sys/dev/isa/if_el.c')
-rw-r--r--sys/dev/isa/if_el.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/sys/dev/isa/if_el.c b/sys/dev/isa/if_el.c
index 0a6d9d27fc3..d0064756bd2 100644
--- a/sys/dev/isa/if_el.c
+++ b/sys/dev/isa/if_el.c
@@ -205,8 +205,8 @@ elattach(parent, self, aux)
bpfattach(&ifp->if_bpf, ifp, DLT_EN10MB, sizeof(struct ether_header));
#endif
- sc->sc_ih = isa_intr_establish(ia->ia_irq, ISA_IST_EDGE, ISA_IPL_NET,
- elintr, sc);
+ sc->sc_ih = isa_intr_establish(ia->ia_irq, IST_EDGE, IPL_NET, elintr,
+ sc);
dprintf(("elattach() finished.\n"));
}
@@ -221,7 +221,7 @@ elreset(sc)
int s;
dprintf(("elreset()\n"));
- s = splimp();
+ s = splnet();
elstop(sc);
elinit(sc);
splx(s);
@@ -296,7 +296,7 @@ elinit(sc)
/*
* Start output on interface. Get datagrams from the queue and output them,
* giving the receiver a chance between datagrams. Call only from splimp or
* interrupt level!
*/
void
@@ -309,7 +309,7 @@ elstart(ifp)
int s, i, off, retries;
dprintf(("elstart()...\n"));
- s = splimp();
+ s = splnet();
/* Don't do anything if output is active. */
if ((ifp->if_flags & IFF_OACTIVE) != 0) {
@@ -392,7 +392,7 @@ elstart(ifp)
outb(iobase+EL_AC, EL_AC_IRQE | EL_AC_RX);
splx(s);
/* Interrupt here. */
- s = splimp();
+ s = splnet();
}
(void)inb(iobase+EL_AS);
@@ -403,7 +403,7 @@ elstart(ifp)
/*
* This function actually attempts to transmit a datagram downloaded to the
* board. Call at splimp or interrupt, after downloading data! Returns 0 on
* success, non-0 on failure.
*/
static int
@@ -620,7 +620,7 @@ elioctl(ifp, cmd, data)
struct ifreq *ifr = (struct ifreq *)data;
int s, error = 0;
- s = splimp();
+ s = splnet();
switch (cmd) {
@@ -296,7 +296,7 @@ elinit(sc)
/*
* Start output on interface. Get datagrams from the queue and output them,
- * giving the receiver a chance between datagrams. Call only from splimp or
+ * giving the receiver a chance between datagrams. Call only from splnet or
* interrupt level!
*/
@@ -403,7 +403,7 @@ elstart(ifp)
/*
* This function actually attempts to transmit a datagram downloaded to the
- * board. Call at splimp or interrupt, after downloading data! Returns 0 on
+ * board. Call at splnet or interrupt, after downloading data! Returns 0 on
* success, non-0 on failure.
*/